import xml.dom.minidom
import click

@click.group('main')
def main():
    pass

@main.command()
@click.argument('input_file', type=click.File('r'))
@click.argument('output_file', type=click.File('w'))
def cmd(input_file, output_file): 
    csv = convert(input_file)
    output_file.write(csv)

def convert(input_file, delim=','):
    output = []
    dom = xml.dom.minidom.parse(input_file)
    rows = dom.getElementsByTagName('Row')
    for row in rows:
        output_row = []
        cells = row.getElementsByTagName('Cell')
        for cell in cells:
            datum = cell.getElementsByTagName('Data')
            if 'ss:MergeAcross' in cell.attributes:
                multiplier = int(cell.attributes['ss:MergeAcross'].value)
            else:
                multiplier = 0
            for data in datum:
                first = data.firstChild
                if first:
                    # XML can have newline chracters in the data value area, which would mess up the formatting in GSheets
                    value_ = first.nodeValue.replace("\n", " ")
                    output_row.append(f'"{value_}"')
                else:
                    output_row.append('')
                if multiplier > 0:
                    output_row.extend([''] * multiplier)
        output.append(delim.join(output_row))

    return '\n'.join(output)

@main.command()
def gui():
    from .gui_model import gui_main
    gui_main(convert)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mb_excelexport_2csv']

package_data = \
{'': ['*']}

install_requires = \
['PyQt6>=6.2.1,<7.0.0', 'click>=8.0.3,<9.0.0']

entry_points = \
{'console_scripts': ['mb_excelexport_2csv = mb_excelexport_2csv.main:main']}

setup_kwargs = {
    'name': 'mb-excelexport-2csv',
    'version': '0.6.0',
    'description': 'Parses an .xls excel file downloaded from ManageBac and converts to comma-deliminated csv. Particularly useful to convert to GSheets without having to use Excel.',
    'long_description': '# mb-excelexport-2csv\n\nThis simple command line tool can be used to take an `.xls` file (that is actually formatted in xml), and output it as a csv. The main use case in mind here is to convert excel files downloaded from ManageBac and upload them to Google Sheets, without having to open Excel.\n\nThis tool provides the exact same output if the xls file was opened in Excel, copied, and then pasted into Google Sheets, but without requiring Excel.\n\n## Getting Started\n\nRequires Python 3.6.1 or above. Install Python 3 at python.org. Installing Python also installs a package manager (called pip) that can install the command `mb_excelexport_2csv` into your command line environment.\n\n`pip3 install mb_excelexport_2csv`\n\nThen, open the mini app using this command:\n\n`mb_excelexport_2csv gui`\n\nFor those who want the command line, use: \n\n`mb_excelexport_2csv cmd`\n\nSee "Command Line" below for more info\n\n### Upgrade\n\nShould you need to update to the latest version, you can do:\n\n`pip install --upgrade mb_excelexport_2csv`\n\n\n## Command Line\n\nAfter pip install worked, it is now installed on your path, and the command mb_excelexport_2csv is now available:\n\n`mb_excelexport_2csv cmd ~/path/to/xml.xls ~/path/to/output.csv`\n\nYou can then import the csv file into Google Sheets. The delimiter used is a comma.\n\nAlternatively, on Mac, you can skip the step of saving the csv file, and just run the following fancy command line, and it\'ll be on your clipboard.\n\n`mb_excelexport_2csv cmd ~/path/to/xml.xls - | pbcopy`\n\nJust paste into "A1" cell of your Google Sheet, Data -> Split Text into Columns.',
    'author': 'Adam Morris',
    'author_email': 'classroomtechtools.ctt@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)



import sys
from PyQt6.QtCore import *
from PyQt6.QtGui import *
from PyQt6.QtWidgets import *

class filedialogdemo(QWidget):
   def __init__(self, convert, parent = None):
      self.convert = convert
      super(filedialogdemo, self).__init__(parent)
		
      layout = QVBoxLayout()

      self.instructions1 = [QLabel("Step 1:"), QLabel("Find the file you downloaded from ManageBac, and we'll convert it to CSV for you.")]
      for instruction in self.instructions1:
         layout.addWidget(instruction)
      self.source = QPushButton("Choose *.xls file")
      self.source.clicked.connect(self.getfile)
		
      layout.addWidget(self.source)
	
      self.instructions2 = [QLabel("Step 2:"), QLabel("Take the output provided below, copy and paste into Google Sheets")]
      for instruction in self.instructions2:
         layout.addWidget(instruction)

      self.contents = QTextEdit()
      doc = self.contents.document()
      option = doc.defaultTextOption()
      option.setFlags(QTextOption.Flag.ShowTabsAndSpaces)
      layout.addWidget(self.contents)

      self.done_btn = QPushButton("Got it! Done")
      self.done_btn.clicked.connect(self.close)
      self.instructions3 = [QLabel("Step 3:"), QLabel("Once pasted into Google Sheets, use Data -> Split Text into Columns"), self.done_btn]
      for instruction in self.instructions3:
         layout.addWidget(instruction)

      self.setLayout(layout)

      self.setWindowTitle("Convert MB Excel Download to CSV")
		
   def getfile(self):
      fname = QFileDialog.getOpenFileName(self, 'Open file', 
         '~/Downloads',"Excel files (*.xls)")
      csv = self.convert(fname[0])
      self.contents.setText(csv)


def gui_main(convert):
   app = QApplication(sys.argv)
   ex = filedialogdemo(convert)
   ex.show()
   sys.exit(app.exec())


if __name__ == '__main__':
   gui_main()

